@@ -1,23 +1,26 @@
-# ABSTRACT: Immutable Data Type Objects for Perl 5
+# ABSTRACT: Immutable Object for Perl 5
 package Data::Object::Immutable;
 
-use 5.10.0;
+use 5.14.0;
 use strict;
 use warnings;
 
 use Data::Object;
+use Data::Object::Signatures;
 use Readonly;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
-sub new {
-    my $self = Data::Object->new($_[1]);
+method new ($data) {
+
+    $self = Data::Object->new($data);
 
     Readonly::Hash   %$self => %$self if UNIVERSAL::isa($self, 'HASH');
     Readonly::Array  @$self => @$self if UNIVERSAL::isa($self, 'ARRAY');
     Readonly::Scalar $$self => $$self if UNIVERSAL::isa($self, 'SCALAR');
 
     return $self;
+
 }
 
 1;
@@ -30,11 +33,11 @@ __END__
 
 =head1 NAME
 
-Data::Object::Immutable - Immutable Data Type Objects for Perl 5
+Data::Object::Immutable - Immutable Object for Perl 5
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
